ComplEx
=======

.. currentmodule:: pykeen.models

.. autoclass:: ComplEx
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ComplEx.hpo_default
      ~ComplEx.loss_default_kwargs
      ~ComplEx.regularizer_default_kwargs

   .. rubric:: Methods Summary

   .. autosummary::

      ~ComplEx.interaction_function
      ~ComplEx.score_hrt

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: loss_default_kwargs
   .. autoattribute:: regularizer_default_kwargs

   .. rubric:: Methods Documentation

   .. automethod:: interaction_function
   .. automethod:: score_hrt
